ax-memory-set
Data structures and operations for managing memory mappings
English | 中文
Introduction
ax-memory-set provides Data structures and operations for managing memory mappings. It is maintained as part of the TGOSKits component set and is intended for Rust projects that integrate with ArceOS, AxVisor, or related low-level systems software.
ax-memory-set was derived from https://github.com/arceos-org/axmm_crates
Quick Start
Installation
Add this crate to your Cargo.toml:
[dependencies]
ax-memory-set = "0.6.1"Run Check and Test
# Enter the crate directory
cd memory/memory_set
# Format code
cargo fmt --all
# Run clippy
cargo clippy --all-targets --all-features
# Run tests
cargo test --all-features
# Build documentation
cargo doc --no-depsIntegration
Example
use ax_memory_set as _;
fn main() {
// Integrate `ax-memory-set` into your project here.
}Documentation
Generate and view API documentation:
cargo doc --no-deps --openOnline documentation: docs.rs/ax-memory-set
Contributing
- Fork the repository and create a branch
- Run local format and checks
- Run local tests relevant to this crate
- Submit a PR and ensure CI passes
License
Licensed under the Apache License, Version 2.0. See LICENSE for details.
Structs
- Memory
Area - A memory area represents a continuous range of virtual memory with the same flags.
- Memory
Set - A container that maintains memory mappings (
MemoryArea).
Enums
- Mapping
Error - Error type for memory mapping operations.
Traits
- Mapping
Backend - Underlying operations to do when manipulating mappings within the specific
MemoryArea.
Type Aliases
- Mapping
Result - A
Resulttype withMappingErroras the error type.