Crate ax_memory_set

Crate ax_memory_set 

ax-memory-set

Data structures and operations for managing memory mappings

Crates.io Docs.rs Rust License

English | 中文

Introduction

ax-memory-set provides Data structures and operations for managing memory mappings. It is maintained as part of the TGOSKits component set and is intended for Rust projects that integrate with ArceOS, AxVisor, or related low-level systems software.

ax-memory-set was derived from https://github.com/arceos-org/axmm_crates

Quick Start

Installation

Add this crate to your Cargo.toml:

[dependencies]
ax-memory-set = "0.6.1"

Run Check and Test

# Enter the crate directory
cd components/axmm_crates/memory_set

# Format code
cargo fmt --all

# Run clippy
cargo clippy --all-targets --all-features

# Run tests
cargo test --all-features

# Build documentation
cargo doc --no-deps

Integration

Example

use ax_memory_set as _;

fn main() {
    // Integrate `ax-memory-set` into your project here.
}

Documentation

Generate and view API documentation:

cargo doc --no-deps --open

Online documentation: docs.rs/ax-memory-set

Contributing

  1. Fork the repository and create a branch
  2. Run local format and checks
  3. Run local tests relevant to this crate
  4. Submit a PR and ensure CI passes

License

Licensed under the Apache License, Version 2.0. See LICENSE for details.

Structs

MemoryArea
A memory area represents a continuous range of virtual memory with the same flags.
MemorySet
A container that maintains memory mappings (MemoryArea).

Enums

MappingError
Error type for memory mapping operations.

Traits

MappingBackend
Underlying operations to do when manipulating mappings within the specific MemoryArea.

Type Aliases

MappingResult
A Result type with MappingError as the error type.